﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using Infragistics.Windows.DataPresenter;

namespace CellTemplcateBasedOnValue
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();

            DataContext = new MainViewModel();
        }

        
        private void Button_Click_1(object sender, RoutedEventArgs e)
        {
            MessageBox.Show("CellStyleSelector");
        }

        private void Button_Click(object sender, RoutedEventArgs e)
        {

        }
    }

    public class MainViewModel
    {

        public MainViewModel()
        {
            Data = new List<Data>
            {
                new Data { },
                new Data { StyleSelector = "text", Trigger = "some" },
                new Data { },
                new Data { StyleSelector = "text", Trigger = "some" },
            };
        }

        public List<Data> Data { get; set; }

        public ICommand CellButtonClicked
        {
            get
            {
                return new RelayCommand<object>(
                    new Action<object>(
                        (obj) => 
                        {
                            Data d = obj as Data;
                            if (d != null)
                                MessageBox.Show("Trigger: " + d);
                        }));
            }
        }
    }

    public class CellStyleSelector : StyleSelector
    {
        public override Style SelectStyle(object item, DependencyObject container)
        {
            CellValuePresenter presenter = container as CellValuePresenter;
            string value = item as string;

            if (string.IsNullOrEmpty(value))
            {
                return presenter.TryFindResource("cellButtonStyle") as Style;
            }
            return base.SelectStyle(item, container);
        }
    }

    public class ShouldShowButtonConverter : IValueConverter
    {
        public object Convert(object value, Type targetType, object parameter, System.Globalization.CultureInfo culture)
        {
            string str = value as string;
            if (string.IsNullOrEmpty(str))
            {
                return true;
            }
            return false;
        }

        public object ConvertBack(object value, Type targetType, object parameter, System.Globalization.CultureInfo culture)
        {
            throw new NotImplementedException();
        }
    }


    public class Data
    {
        public string StyleSelector { get; set; }
        public string Trigger { get; set; }
    }

    public class RelayCommand<T> : ICommand
    {

        #region Declarations

        readonly Predicate<T> _canExecute;
        readonly Action<T> _execute;

        #endregion

        #region Constructors

        /// <summary>
        /// Initializes a new instance of the <see cref="RelayCommand&lt;T&gt;"/> class and the command can always be executed.
        /// </summary>
        /// <param name="execute">The execution logic.</param>
        public RelayCommand(Action<T> execute)
            : this(execute, null)
        {
        }

        /// <summary>
        /// Initializes a new instance of the <see cref="RelayCommand&lt;T&gt;"/> class.
        /// </summary>
        /// <param name="execute">The execution logic.</param>
        /// <param name="canExecute">The execution status logic.</param>
        public RelayCommand(Action<T> execute, Predicate<T> canExecute)
        {

            if (execute == null)
                throw new ArgumentNullException("execute");
            _execute = execute;
            _canExecute = canExecute;
        }

        #endregion

        #region ICommand Members

        public event EventHandler CanExecuteChanged
        {
            add
            {

                if (_canExecute != null)
                    CommandManager.RequerySuggested += value;
            }
            remove
            {

                if (_canExecute != null)
                    CommandManager.RequerySuggested -= value;
            }
        }

        public virtual Boolean CanExecute(Object parameter)
        {
            return _canExecute == null ? true : _canExecute((T)parameter);
        }

        public virtual void Execute(Object parameter)
        {
            _execute((T)parameter);
        }

        #endregion
    }

}
